<TeXmacs|1.0.6.11>

<style|source>

<\body>
  <\active*>
    <\src-title>
      <src-style-file|seminar|1.0>

      <\src-purpose>
        The seminar style.
      </src-purpose>

      <\src-copyright|1998--2004>
        Joris van der Hoeven
      </src-copyright>

      <\src-license>
        This software falls under the <hlink|GNU general public
        license, version 3 or later|$TEXMACS_PATH/LICENSE>.
        It comes WITHOUT ANY WARRANTY WHATSOEVER.
        You should have received a copy of the license which the software.
        If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
      </src-license>
    </src-title>
  </active*>

  <use-package|std|env|title-seminar|header-seminar|section-seminar>

  \;

  <assign|magnification|2>

  <assign|par-first|0fn>

  <assign|page-odd|15mm>

  <assign|page-even|15mm>

  <assign|page-top|15mm>

  <assign|page-bot|20mm>

  <assign|page-reduce-left|0mm>

  <assign|page-reduce-right|0mm>

  <assign|page-reduce-top|0mm>

  <assign|page-reduce-bot|0mm>

  \;

  <assign|em|<macro|x|<with|color|blue|<arg|x>>>>

  \;
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>